<?php

namespace Drupal\sitemap\Tests;

/**
 * Tests the display of RSS links based on sitemap settings.
 *
 * @group sitemap
 */
class SitemapFrontpageTest extends SitemapBrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['sitemap'];

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    // Create user, then login.
    $this->user = $this->drupalCreateUser([
      'administer sitemap',
      'access sitemap',
    ]);
    $this->drupalLogin($this->user);
  }

  /**
   * Tests the custom title setting.
   */
  public function testCustomTitle() {

    // Assert that main menu is included in the sitemap.
    $this->drupalGet('/sitemap');
    $elements = $this->cssSelect(".sitemap-plugin--frontpage h2:contains('Front page')");
    $this->assertEqual(count($elements), 1, 'Default title is included.');

    // Remove the title for the main menu.
    $this->saveSitemapForm(['plugins[frontpage][settings][title]' => '']);
    // @TODO: Add plugin render cache tags.
    drupal_flush_all_caches();

    // Check that a title does not appear on sitemap.
    $this->drupalGet('/sitemap');
    $elements = $this->cssSelect(".sitemap-plugin--frontpage h2:contains('Front page')");
    $this->assertEqual(count($elements), 0, 'Title is not included.');

    // Set a custom title for the main menu display.
    $custom_title = $this->randomString();
    $this->saveSitemapForm(['plugins[frontpage][settings][title]' => $custom_title]);
    // @TODO: Add plugin render cache tags.
    drupal_flush_all_caches();

    // Check that the custom title appears on the sitemap.
    $this->drupalGet('/sitemap');
    $elements = $this->cssSelect(".sitemap-plugin--frontpage h2:contains('" . $custom_title . "')");
    $this->assertEqual(count($elements), 1, 'Custom title is included.');
  }

  /**
   * Tests RSS feed for front page.
   */
  public function testRssFeed() {
    // Assert default RSS feed for front page.
    $this->drupalGet('/sitemap');
    $this->assertLinkByHref('/rss.xml');

    // Change RSS feed for front page.
    $href = mb_strtolower($this->randomMachineName());
    $this->saveSitemapForm(['plugins[frontpage][settings][rss]' => $href]);

    // Assert that RSS feed for front page has been changed.
    $this->drupalGet('/sitemap');
    $this->assertLinkByHref('/' . $href);
  }

}
