<?php

namespace Drupal\sitemap\Tests;

/**
 * Test the display of menus based on sitemap settings.
 *
 * @group sitemap
 */
class SitemapMenuCustomTitleTest extends SitemapMenuTestBase {

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    // Configure module to show main menu.
    $edit = [
      'plugins[menu:main][enabled]' => TRUE,
    ];
    $this->saveSitemapForm($edit);

    // Create test node with enabled menu item.
    $edit = [
      'title[0][value]' => $this->randomString(),
      'menu[enabled]' => TRUE,
      'menu[title]' => $this->randomString(),
      // In order to make main navigation menu displayed, there must be at least
      // one child menu item of that menu.
      'menu[menu_parent]' => 'main:',
    ];
    $this->drupalPostForm('node/add/article', $edit, t('Save'));
  }

  /**
   * Tests a custom title setting for menus.
   */
  public function testMenusCustomTitle() {

    // Assert that main menu is included in the sitemap.
    $default_menu_name = 'Main navigation';
    $this->drupalGet('/sitemap');
    $elements = $this->cssSelect(".sitemap-plugin--menu h2:contains(" . $default_menu_name . ")");
    $this->assertEqual(count($elements), 1, 'Menu with default title is included.');

    // Remove the title for the main menu.
    $this->saveSitemapForm(['plugins[menu:main][settings][title]' => '']);
    // @TODO: Do we still need this?
    drupal_flush_all_caches();

    // Check that a title does not appear on sitemap.
    $this->drupalGet('/sitemap');
    $elements = $this->cssSelect(".sitemap-plugin--menu h2:contains('" . $default_menu_name . "')");
    $this->assertEqual(count($elements), 0, 'Menu title is not included.');

    // Set a custom title for the main menu display.
    $custom_title = $this->randomString();
    $this->saveSitemapForm(['plugins[menu:main][settings][title]' => $custom_title]);
    // @TODO: Do we still need this?
    drupal_flush_all_caches();

    // Check that the custom title appears on the sitemap.
    $this->drupalGet('/sitemap');
    $elements = $this->cssSelect(".sitemap-plugin--menu h2:contains('" . $custom_title . "')");
    $this->assertEqual(count($elements), 1, 'Menu custom title is included.');
  }

}
